# llm_discord_bot
LLM Discord Bot


## Versions

### 2.0.1

- fix typing indicator

### 2.0.0

- overhaul multi participant conversation prompt handling

### 1.0.1

- stop agents from replying to mentions meant for others
- only reply to non-bots in monitored channels

### 1.0.0

- initial version

